#
# spec file for package librealsense
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libver %(echo %version|sed 's@^\\([0-9]*\\)\\.\\([0-9]*\\).*@\\1_\\2@')

Name:           librealsense
Version:        2.56.1
Release:        1.1
Summary:        Library for Intel RealSense depth cameras
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            https://github.com/IntelRealSense/librealsense
Source:         https://github.com/IntelRealSense/librealsense/archive/v%{version}.tar.gz
Patch0:         presets_path.patch
Patch1:         disable-pedantic.patch
Patch2:         0001-third-party-use-nlohmann_json-from-system.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  cmake(FreeGLUT)
BuildRequires:  cmake(glfw3) >= 3.3
BuildRequires:  cmake(nlohmann_json) >= 3.11.3
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libglvnd)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libusb-1.0)

%description
The SDK allows depth and color streaming, and provides intrinsic and extrinsic
calibration information. The library also offers synthetic streams (pointcloud,
depth aligned to color and vise-versa), and a built-in support for record and
playback of streaming sessions.

%package -n %{name}%{libver}
Summary:        Library for Intel RealSense depth cameras
Group:          System/Libraries

%description -n %{name}%{libver}
Library for Intel RealSense depth cameras applications.

%package devel
Summary:        Headers and library for librealsense
Group:          Development/Libraries/C and C++
Requires:       %{name}%{libver} = %{version}-%{release}

%description devel
Headers and cmake project files for developing librealsense applications.

%package examples
Summary:        Examples for librealsense
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description examples
Examples from the librealsense library.

%prep
%autosetup -p1

%build
%define __builder ninja
# there is a *lot* of those warnings
export CXXFLAGS='%optflags -Wno-reorder -Wno-unused-variable -Wno-sign-compare -Wno-unknown-pragmas'
sed -i "s/‘\|\’/\'/g" %{_builddir}/%{name}-%{version}/src/libusb/libusb.h
%cmake \
	-DOpenGL_GL_PREFERENCE=GLVND \
	-DCHECK_FOR_UPDATES=OFF \
	-DIMPORT_DEPTH_CAM_FW=OFF
%cmake_build

%install
%cmake_install

rm -f %{buildroot}/%{_libdir}/*.a

install -d %{buildroot}/%{_udevrulesdir}
install -m 644 -t %{buildroot}/%{_udevrulesdir} config/99-realsense-libusb.rules

%fdupes %{buildroot}/%{_libdir}/cmake/

%post -n %{name}%{libver} -p /sbin/ldconfig
%postun -n %{name}%{libver} -p /sbin/ldconfig

%files
%doc readme.md CONTRIBUTING.md code-of-conduct.md NOTICE.md Security.md
%{_bindir}/realsense-viewer
%dir %{_datadir}/librealsense2/
%dir %{_datadir}/librealsense2/presets/
%{_datadir}/librealsense2/presets/*.preset
%{_udevrulesdir}/99-realsense-libusb.rules

%files -n %{name}%{libver}
%license LICENSE
%{_libdir}/librealsense*.so.*

%files devel
%{_includedir}/librealsense2
%{_includedir}/librealsense2-gl
%{_libdir}/librealsense*.so
%dir %{_libdir}/cmake/realsense2
%dir %{_libdir}/cmake/realsense2-gl
%{_libdir}/cmake/realsense2/*.cmake
%{_libdir}/cmake/realsense2-gl/*.cmake
%{_libdir}/pkgconfig/realsense2*.pc

%files examples
%{_bindir}/rs-*

%changelog
* Mon Sep 30 2024 Jiri Slaby <jslaby@suse.cz>
- Update to 2.56.1
  * see release notes here:
    https://github.com/IntelRealSense/librealsense/releases/tag/v2.56.1
- drop gcc-13-include-cstdint-for-int-_t.patch (in upstream)
- add 0001-third-party-use-nlohmann_json-from-system.patch
* Wed Oct  4 2023 Alessandro de Oliveira Faria <cabelo@opensuse.org>
- Update to 2.54.2
  * see release notes here:
    https://github.com/IntelRealSense/librealsense/releases/tag/v2.54.2
* Tue Jul 11 2023 Jiri Slaby <jslaby@suse.cz>
- Update to 2.54.1
  * see release notes here:
    https://github.com/IntelRealSense/librealsense/releases/tag/v2.54.1
* Tue Mar 28 2023 Jiri Slaby <jslaby@suse.cz>
- add gcc-13-include-cstdint-for-int-_t.patch
* Mon Jan  9 2023 Jiri Slaby <jslaby@suse.cz>
- Update to 2.53.1
  * see release notes here:
    https://github.com/IntelRealSense/librealsense/releases/tag/v2.53.1
- Drop old "Obsoletes" -- no current distro provides that.
* Mon Sep  5 2022 Alessandro de Oliveira Faria <cabelo@opensuse.org>
- Update to 2.51.1
  * see release notes here:
    https://github.com/IntelRealSense/librealsense/releases/tag/v2.51.1
* Thu Apr 28 2022 Jiri Slaby <jslaby@suse.cz>
- Update to 2.50.0
  * see release notes here:
    https://github.com/IntelRealSense/librealsense/releases/tag/v2.50.0
- add
  * disable-pedantic.patch
  * presets_path.patch
* Wed Apr 27 2022 Jan Engelhardt <jengelh@inai.de>
- Resolve rpmlint report "librealsense2.x86_64: E:
  shlib-policy-name-error SONAME: librealsense2-gl.so.2.44,
  expected package suffix: 2_44"
* Tue May 25 2021 Alessandro de Oliveira Faria <cabelo@opensuse.org>
- Update to 2.44.0
  * see release notes here:
    https://github.com/IntelRealSense/librealsense/releases/tag/v2.44.0
* Tue Mar 30 2021 Jiri Slaby <jslaby@suse.cz>
- Update to 2.43.0
  * see release notes here:
    https://github.com/IntelRealSense/librealsense/releases/tag/v2.43.0
* Mon Feb 22 2021 Jiri Slaby <jslaby@suse.cz>
- Update to 2.42.0
  * see release notes here:
    https://github.com/IntelRealSense/librealsense/releases/tag/v2.42.0
* Fri Sep 25 2020 Jiri Slaby <jslaby@suse.cz>
- Update to 2.38.1
  * see release notes here:
    https://github.com/IntelRealSense/librealsense/releases/tag/v2.38.1
- Drop 0001-Fix-aarch64-arm-detection.patch as it is upstream
- Switch from snapshots to releases
* Wed Apr 29 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix build on %%arm and aarch64:
  * 0001-Fix-aarch64-arm-detection.patch
* Wed Mar 11 2020 christophe@krop.fr
- Update to version 2.33.1+git20200305.ge0b160f01:
  * Promote D4xx firmware version to 5.12.3.0
  * Comment on the wrappers
  * Rectify license of the INF file
  * Reverting merge mistake
  * Bump version to v2.33.1
  * Fix memory leak in v4l2 backend on kernel 5.3
  * lines reordered in rder to log before exception throw
  * using log instead of LOGGER_ERROR because of linkage correction in windows
  * minor changes from code review
  * fw update crash fix
  * revert void*->char* change to preserve backwards compat
  * and much more...
* Wed Mar 11 2020 Christophe Giboudeaux <christophe@krop.fr>
- Require freeglut-devel instead of pkgconfig(freeglut).
  The pkgconfig name changed in Tumbleweed.
* Fri Feb  7 2020 Jiri Slaby <jslaby@suse.com>
- drop src/win* files as they contain weird license
* Thu Feb  6 2020 Jiri Slaby <jslaby@suse.com>
- add _constraints (4G of RAM)
* Wed Feb  5 2020 jslaby@suse.com
- Update to version 2.32.1+git20200123.g83f952a4b:
  * Promote the recommended FW to v5.12.2.100
  * Re-enable back light compensation for the D465 - adding to this branch to not forget to merge
  * fix possible bug in device-hid detection
  * Add support for remove_static_node
  * Update readme.md
  * Add heuristic to drop UVC overflow frames with v4l kernel prior to v4.16
  * use ts.global_ts for update
  * chrono::abs() not supported on pre-c++17
  * image time sync code update
  * and much more...
* Thu Dec 12 2019 Jiri Slaby <jslaby@suse.com>
- initial commit
